pub enum TokenRotationError {
TokenRejected(BearerTokenError),
StateUnavailable,
}Expand description
Bearer-token validation or rotation failure.
Variants
TokenRejected(BearerTokenError)
The replacement bearer token was rejected before state changed.
The credential state could not be read or changed.